package Logica;
import java.io.Serializable;
import java.util.Vector;

public class Gestion implements Serializable{
	private Vector<Transaccion> gestiones;
	private float suma;
	private  float total;
	private boolean isPositivo;
	private String nombre;
	
	/**
	 * Constructor principal de gestion
	 * 
	 * @param nombre		nombre de la gestion
	 * @param isPositivo	si es verdadero la gestion sera de beneficios, si es falsa sera de gastos
	 */
	public Gestion(String nombre, boolean isPositivo) {
		this.gestiones = new Vector<Transaccion>();
		this.suma = 0;
		this.total = 0;
		this.nombre = nombre;
		this.isPositivo = isPositivo;
	}
	
	/**
	 * Devuelve el nombre de la gestion
	 * 
	 * @return	nombre de la gestion
	 */
	public String getNombre() {
		return this.nombre;
	}
	
	public void setNombre(String nombre) {
		this.nombre = nombre;
	}
	
	/**
	 * Aniade una transaccion a la gestion
	 * 
	 * @param transaccion	transaccion que sera aniadida a la gestion
	 */
	public void aniadirGasto(Transaccion transaccion) {
		this.gestiones.add(transaccion);
		this.suma += transaccion.getDinero();
		if(this.isPositivo) {
			this.total += transaccion.getDinero();
		}else {
			this.total -= transaccion.getDinero();
		}
	}
	
	/**
	 * Devuelve la suma (sin tener e cuenta si es gasto o ingreso) de la gestion
	 * 
	 * @return	suma de las transacciones de la gestion
	 */
	public float getSuma() {
		return this.suma;
	}
	
	/**
	 * Devuelve la suma de todos sus datos, esta vez teniendo en cuenta si debe sumar o restar
	 * 
	 * @return	suma correcta de los datos
	 */
	public float getTotal() {
		return this.total;
	}
	
	/**
	 * Devuelve todas las transacciones que tiene
	 * 
	 * @return	Transacciones que contiene
	 */
	public Vector<Transaccion> getElementos(){
		return this.gestiones;
	}
	
	/**
	 * Elimina una transaccion
	 * 
	 * @param transaccion	transaccion a eliminar
	 */
	public void eliminarTransaccion(String transaccion) {
		for(Transaccion elemento:this.gestiones) {
			if(elemento.toString().equals(transaccion)) {
				this.gestiones.remove(elemento);
				return;
			}
		}
	}
	
	public void editarTransaccion(String nombreViejo, String nombreNuevo) {
		for(Transaccion elemento:this.gestiones) {
			if(elemento.getNombre().equals(nombreViejo)) {
				elemento.setName(nombreNuevo);
				return;
			}
		}
	}
	
	/**
	 * Devuelve verdadero si es un ingerso y falso si es un gasto
	 * 
	 * @return verdadero si es ingersos y falso si sin gastos
	 */
	public boolean esIngreso() {
		return this.isPositivo;
	}
	
	/**
	 * Permite alterar la visibilidad de un elemento
	 * 
	 * @param elemento	indice del elemento a alterar
	 */
	public void alterarVisibilidad(int elemento) {
		if(this.gestiones.get(elemento).alterarVisivilidad()) {
			this.suma += this.gestiones.get(elemento).getDinero();
			if(this.isPositivo) {
				this.total += this.gestiones.get(elemento).getDinero();
			}else {
				this.total -= this.gestiones.get(elemento).getDinero();
			}
		}else {
			this.suma -= this.gestiones.get(elemento).getDinero();
			if(this.isPositivo) {
				this.total -= this.gestiones.get(elemento).getDinero();
			}else {
				this.total += this.gestiones.get(elemento).getDinero();
			}
		}
	}
	
	public String toString() {
		String ret = "";
		ret += this.nombre + " " + this.suma + " " + this.isPositivo;
		return ret;
	}

}
